#
# spec file for package libpff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libpff
%define lname	libpff1
Version:        20231205
Release:        2.5
Summary:        Library and tools to access Microsoft PFF/OFF/PST/OST/PAB files
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libpff
Source:         https://github.com/libyal/libpff/releases/download/%version/libpff-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libpff/releases/download/%version/libpff-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source12:       PFF_Forensics_-_analyzing_the_horrible_reference_file_format.pdf
Source13:       PFF_forensics_-_e-mail_and_appoinment_falsification_analysis.pdf
Source14:       Personal_Folder_File_PFF_format.pdf
Source15:       MAPI_definitions.pdf
Source16:       libpff-libfdata.pdf
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20230108
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20221218
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libfcache) >= 20230115
BuildRequires:  pkgconfig(libfdata) >= 20230319
BuildRequires:  pkgconfig(libfdatetime) >= 20220112
BuildRequires:  pkgconfig(libfguid) >= 20220113
BuildRequires:  pkgconfig(libfmapi) >= 20230408
BuildRequires:  pkgconfig(libfvalue) >= 20220120
BuildRequires:  pkgconfig(libfwnt) >= 20231124
BuildRequires:  pkgconfig(libuna) >= 20230710
BuildRequires:  pkgconfig(zlib)
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libpff is a library to access the Personal Folder File (PFF) and the
Offline Folder File (OFF) format. These are used in several file
Types: PAB (Personal Address Book), PST (Personal Storage Table) and
OST (Offline Storage Table).

%package -n %lname
Summary:        Library to access Microsoft PFF and OFF format files
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libpff is a library to access the Personal Folder File (PFF) and the
Offline Folder File (OFF) format. These are used in several file
Types: PAB (Personal Address Book), PST (Personal Storage Table) and
OST (Offline Storage Table).

%package tools
Summary:        Tools to access Microsoft PST and OST files
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities
Requires:       %lname = %version

%description tools
Tools to access the Personal Folder File (PFF) and the Offline Folder
File (OFF) format. These are used in several file types: PAB
(Personal Address Book), PST (Personal Storage Table) and OST
(Offline Storage Table).

%package devel
Summary:        Development files for libpff, a PFF/OFF file format library
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libpff is a library to access the Personal Folder File (PFF) and the
Offline Folder File (OFF) format. These are used in several file
Types: PAB (Personal Address Book), PST (Personal Storage Table) and
OST (Offline Storage Table).

This subpackage contains libraries and header files for developing
applications that want to make use of libpff.

%prep
%autosetup -p1
cp -av %_sourcedir/*.pdf .

%build
echo "V_%version { global: *; };" >sym.ver
%{python_expand #
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}"
grep ' '' ''local' config.log && exit 1
%make_build LDFLAGS="-Wl,--version-script=$PWD/sym.ver"
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* "%buildroot/"
find "%buildroot" -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libpff.so.*

%files -n %name-tools
%license COPYING*
%_bindir/pff*
%_mandir/man1/pff*.1*

%files -n %name-devel
%doc MAPI_definitions.pdf
%doc PFF_Forensics_-_analyzing_the_horrible_reference_file_format.pdf
%doc PFF_forensics_-_e-mail_and_appoinment_falsification_analysis.pdf
%doc Personal_Folder_File_*.pdf
%_includedir/libpff.h
%_includedir/libpff/
%_libdir/libpff.so
%_libdir/pkgconfig/libpff.pc
%_mandir/man3/libpff.3*

%files %python_files
%python_sitearch/pypff.so

%changelog
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Tue Dec  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231205
  * No user-visible changes
* Thu Nov 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231130
  * RTF body decompression used wrong argument order, now fixed
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Sun Mar 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20230225
  * Adjust for changed libfdata API
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Replace pkgconfig.diff by a Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Edit specfile to do multipython builds.
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211114
  * Improved compressed OST format support
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210508 (b736acdd)
  * No changelog was provided
- Add system-libs.patch
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- convert python bindings to python3
- rename the binding submodule from python-libpff to python3-libpff
* Tue Apr  2 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- Updated to v0~20180714
  * several bug fixes
  * see github log
- update which internal packages from libyal are used.  Now only libcpath
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- Updated to v0~20161119
  * changes only provided in gitlog
- Renamed Personal_Folder_File_PFF_format.pdf to meet new naming rules
- correct URL and Source fields to the new github location
- Clean-up BuildRequires to use external packages as feasible
* Mon Oct 17 2016 jengelh@inai.de
- Add pkgconfig.diff; adds libbfio as a require into the .pc file
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- updated to v0~20131018
  * worked on python bindings
  * updated dependencies
  * worked on setup.py, largely for MSI builds
  * code clean up
  * added libcthreads build support
  * worked tests
  * refactored local descriptors
  * worked on compressed OST support
  - local descriptors
  - table reference
  - data array
  - table reference
  * worked on recovery in compressed OST files
  * updated dependencies
  * worked on record entry values array number out of bounds issue
  * refactored table index values to use libcdata array
  * fixed invalid return code in error path
  * worked on fixing out of bounds read of name to id map string in an error
  toloreant way
  * Added is corrupted function
  * worked on name to id map string out of bounds issue
  * worked on record entry values array number out of bounds issue
  * Worked on 64-bit 4k pages support
  * Worked on item recovery
- Clean-up BuildRequires to use external packages as feasible
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- update to v0~20130722
  * major refactor of code, packaged redesignated experimental
  * Worked on compressed OST support
  * worked on pypff
  * worked on tests
  * fix for handling floating point values in item file
  * updated dependencies
  * worked on API by_utf8_name and by_utf16_name functions
  * worked on libcdata rewrite
  * worked on libfdata update
  * worked on 64-bit 4k page file format support
  * bug fixes in error path
  * improved debug output
  * pffexport:
  - worked on IPM.DistList support
  - added message flags
  - improved output of flag types
  * libfmapi
  - improved debug output
  - fixes in error code paths
  * tests:
  - added pffinfo test
  * 2013 update
- changed to gz compression to simplyfy download/convert
- use all libyal factory packages possible
* Mon Apr 29 2013 kaanozdincer@gmail.com
- Make specfile more consistent with the other Joachim Metz packages.
- Move developer docs to devel package.
* Fri Apr  5 2013 jengelh@inai.de
- Cleanups: Set RPM group, summary and description metadata
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Apr  3 2013 Greg.Freemyer@gmail.com
- Put documentation in -devel; do not bloat the shlib package
- Set licenses in each sub-package
- Remove unused %%py_requires
* Mon Apr  1 2013 Greg.Freemyer@gmail.com
- initial package (version 0.0.0~20120802) - alpha quality software
